import abc
import builtins
import datetime
import enum
import typing

import jsii
import publication
import typing_extensions

import aws_cdk.aws_codebuild._jsii
import aws_cdk.aws_codepipeline._jsii
import aws_cdk.aws_codepipeline_actions._jsii
import aws_cdk.aws_events_targets._jsii
import aws_cdk.aws_iam._jsii
import aws_cdk.aws_lambda._jsii
import aws_cdk.aws_s3._jsii
import aws_cdk.aws_secretsmanager._jsii
import aws_cdk.aws_ssm._jsii
import aws_cdk.core._jsii
import constructs._jsii

__jsii_assembly__ = jsii.JSIIAssembly.load(
    "cdk-codepipeline-badge-notification",
    "0.2.39",
    __name__[0:-6],
    "cdk-codepipeline-badge-notification@0.2.39.jsii.tgz",
)

__all__ = [
    "__jsii_assembly__",
]

publication.publish()
